from operator import invert
from paho.mqtt import client as mqtt_client

class Publisher:
    def __init__(self, host, port, client_id, username, password, topic):
        self.host = host
        self.port = port
        self.client_id = client_id
        self.username = username
        self.password = password
        self.topic = topic
        self.client = mqtt_client.Client(client_id)

        def on_connect(client, userdata, flags, rc):
            if rc == 0:
                print("Connected to MQTT Broker!")
            else:
                print("Failed to connect, return code %d\n", rc)
        def on_disconnect(client, userdata, rc):
            print("Disconnecting reason  "  +str(rc))
        self.on_connect = on_connect
        self.on_disconnect = on_disconnect

        self._connect()

    def _connect(self):
        self.client.username_pw_set(self.username, self.password)
        self.client.connect(self.host, self.port)

    def _publish(self, subtopic, data):
        topic = self.topic+subtopic
        result = self.client.publish(topic, data)
        status = result[0]
        if status == 0:
            print(f"Send `{data}` to topic `{topic}`")
        else:
            print(f"Failed to send message to topic {topic}")

    def send_single_value(self, subtopic, value, inverter_address):
        if value:
            self._publish("{0}/{1}".format(inverter_address, subtopic), value)